@@ -197,6 +197,60 @@ class ToEventSum(object):
     def __repr__(self):
         return self.__class__.__name__ + '()'
 
+class FilterEvents(object):
+    def __init__(self, kernel = None, groups = 1, tpad = None):
+        self.kernel = kernel
+        self.groups = groups
+        if tpad is None:
+            self.tpad = self.kernel.shape[2]//2
+        else:
+            self.tpad = tpad
+
+    def __call__(self, chunks):
+        if len(chunks.shape)==4:
+            data = chunks.permute([1,0,2,3])
+            data = data.unsqueeze(0)
+        else:
+            data = chunks.permute([0,2,1,3,4])
+
+        Y = torch.nn.functional.conv3d(data, self.kernel, groups=self.groups, padding= [self.tpad,0,0])
+        Y = Y.transpose(1,2)
+        if len(chunks.shape)==4:
+            return Y[0]
+        else:
+            return Y
+
+class ExpFilterEvents(FilterEvents):
+    def __init__(self, length, tau=200, channels=2, tpad = None, device='cpu', **kwargs):
+        t = torch.arange(0.,length,1.)
+        kernel = torch.ones(channels, 1, len(t), 1, 1)
+        exp_kernel = torch.exp(-t/tau)
+        exp_kernel/=exp_kernel.sum()
+        exp_kernel=torch.flip(exp_kernel,[0]) #Conv3d is cross correlation not convolution
+        groups = 2
+
+        for i in range(channels):
+            kernel[i,0,:,0,0]=exp_kernel
+        kernel = kernel.to(device)
+
+        super(ExpFilterEvents, self).__init__(kernel, groups, tpad, **kwargs)
+
+class Rescale(object):
+    """Rescale the event sum Tensor by the given factor.
+
+    Args:
+        factor: : Desired rescale factor. 
+    """
+    def __init__(self, factor):
+        self.factor = factor
+
+    def __call__(self, chunks):
+        return chunks*self.factor
+
+    def __repr__(self):
+        return self.__class__.__name__ + '({0})'.format(self.factor)
+
+
 
 class Repeat(object):
     '''
@@ -217,6 +271,9 @@ class ToTensor(object):
     Converts a numpy.ndarray to a torch.FloatTensor of the same shape
     """
 
+    def __init__(self, device='cpu'):
+        self.device=device
+
     def __call__(self, frame):
         """
         Args:
@@ -225,7 +282,7 @@ class ToTensor(object):
         Returns:
             Tensor: Converted data.
         """
-        return torch.FloatTensor(frame)
+        return torch.FloatTensor(frame).to(self.device)
 
     def __repr__(self):
-        return self.__class__.__name__ + '()'
+        return self.__class__.__name__ + '(device:{0})'.format(self.device)
